fedex.services.package_movement.FedexInvalidPostalCodeFormat

Package fedex :: Package services :: Module package_movement :: Class FedexInvalidPostalCodeFormat |
[hide private]
[frames] | no frames]

# Class FedexInvalidPostalCodeFormat

source code

Exception: Sent when the postal code is invalid

Instance Methods | [hide private]
Inherited from `base_service.FedexBaseServiceException`: `__init__`, `__str__`, `__unicode__` Inherited from `exceptions.Exception`: `__new__` Inherited from `exceptions.BaseException`: `__delattr__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__reduce__`, `__repr__`, `__setattr__`, `__setstate__` Inherited from `object`: `__format__`, `__hash__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Properties | [hide private]
Inherited from `exceptions.BaseException`: `args`, `message` Inherited from `object`: `__class__`